@@ -7,11 +7,11 @@ init()
 ### Generate balanced fake data.
 comm.set.seed(1234, diff = TRUE)
 N <- 100                  # Pretend N is large.
-x.spmd <- rnorm(N)        # Distributed data.
+x.gbd <- rnorm(N)         # Distributed data.
 
 ### Run.
-ret.spmd <- demo.quantile(x.spmd)
+ret.gbd <- demo.quantile(x.gbd)
 
 ### Output.
-comm.print(ret.spmd)
+comm.print(ret.gbd)
 finalize()
